@@ -8,7 +8,7 @@ use zellij_tile::prelude::*;
 use zellij_tile_utils::style;
 
 use first_line::{ctrl_keys, superkey};
-use second_line::keybinds;
+use second_line::{keybinds, text_copied_hint};
 
 // for more of these, copy paste from: https://en.wikipedia.org/wiki/Box-drawing_character
 static ARROW_SEPARATOR: &str = "";
@@ -17,6 +17,7 @@ static MORE_MSG: &str = " ... ";
 #[derive(Default)]
 struct State {
     mode_info: ModeInfo,
+    diplay_text_copied_hint: bool,
 }
 
 register_plugin!(State);
@@ -134,14 +135,25 @@ fn color_elements(palette: Palette) -> ColoredElements {
 impl ZellijPlugin for State {
     fn load(&mut self) {
         set_selectable(false);
-        set_invisible_borders(true);
-        set_fixed_height(2);
-        subscribe(&[EventType::ModeUpdate]);
+        subscribe(&[
+            EventType::ModeUpdate,
+            EventType::CopyToClipboard,
+            EventType::InputReceived,
+        ]);
     }
 
     fn update(&mut self, event: Event) {
-        if let Event::ModeUpdate(mode_info) = event {
-            self.mode_info = mode_info;
+        match event {
+            Event::ModeUpdate(mode_info) => {
+                self.mode_info = mode_info;
+            }
+            Event::CopyToClipboard => {
+                self.diplay_text_copied_hint = true;
+            }
+            Event::InputReceived => {
+                self.diplay_text_copied_hint = false;
+            }
+            _ => {}
         }
     }
 
@@ -154,10 +166,18 @@ impl ZellijPlugin for State {
 
         let colored_elements = color_elements(self.mode_info.palette);
         let superkey = superkey(colored_elements, separator);
-        let ctrl_keys = ctrl_keys(&self.mode_info, cols - superkey.len, separator);
+        let ctrl_keys = ctrl_keys(
+            &self.mode_info,
+            cols.saturating_sub(superkey.len),
+            separator,
+        );
 
         let first_line = format!("{}{}", superkey, ctrl_keys);
-        let second_line = keybinds(&self.mode_info, cols);
+        let second_line = if self.diplay_text_copied_hint {
+            text_copied_hint(&self.mode_info.palette)
+        } else {
+            keybinds(&self.mode_info, cols)
+        };
 
         // [48;5;238m is gray background, [0K is so that it fills the rest of the line
         // [m is background reset, [0K is so that it clears the rest of the line
