@@ -34,9 +34,7 @@ fn setup_remote_environment(channel: &mut ssh2::Channel, win_size: Size) {
         .request_pty("xterm", None, Some((columns, rows, 0, 0)))
         .unwrap();
     channel.shell().unwrap();
-    channel
-        .write_all(format!("export PS1=\"$ \"\n").as_bytes())
-        .unwrap();
+    channel.write_all("export PS1=\"$ \"\n".as_bytes()).unwrap();
     channel.flush().unwrap();
 }
 
@@ -154,7 +152,7 @@ impl<'a> RemoteTerminal<'a> {
         format!("x: {}, y: {}", self.cursor_x, self.cursor_y)
     }
     pub fn send_key(&mut self, key: &[u8]) {
-        self.channel.write(key).unwrap();
+        self.channel.write_all(key).unwrap();
         self.channel.flush().unwrap();
     }
     pub fn change_size(&mut self, cols: u32, rows: u32) {
