@@ -3,6 +3,7 @@ pub mod os_input_output;
 mod command_is_executing;
 mod input_handler;
 
+use log::info;
 use std::env::current_exe;
 use std::io::{self, Write};
 use std::path::Path;
@@ -13,14 +14,14 @@ use crate::{
     command_is_executing::CommandIsExecuting, input_handler::input_loop,
     os_input_output::ClientOsApi,
 };
-use zellij_utils::cli::CliArgs;
 use zellij_utils::{
     channels::{self, ChannelWithContext, SenderWithContext},
     consts::{SESSION_NAME, ZELLIJ_IPC_PIPE},
     errors::{ClientContext, ContextType, ErrorInstruction},
-    input::{actions::Action, config::Config, layout::Layout, options::Options},
+    input::{actions::Action, config::Config, options::Options},
     ipc::{ClientAttributes, ClientToServerMsg, ExitReason, ServerToClientMsg},
 };
+use zellij_utils::{cli::CliArgs, input::layout::LayoutFromYaml};
 
 /// Instructions related to the client-side application
 #[derive(Debug, Clone)]
@@ -85,9 +86,11 @@ pub fn start_client(
     mut os_input: Box<dyn ClientOsApi>,
     opts: CliArgs,
     config: Config,
+    config_options: Options,
     info: ClientInfo,
-    layout: Option<Layout>,
+    layout: Option<LayoutFromYaml>,
 ) {
+    info!("Starting Zellij client!");
     let clear_client_terminal_attributes = "\u{1b}[?1l\u{1b}=\u{1b}[r\u{1b}12l\u{1b}[?1000l\u{1b}[?1002l\u{1b}[?1003l\u{1b}[?1005l\u{1b}[?1006l\u{1b}[?12l";
     let take_snapshot = "\u{1b}[?1049h";
     let bracketed_paste = "\u{1b}[?2004h";
@@ -103,7 +106,6 @@ pub fn start_client(
         .unwrap();
     std::env::set_var(&"ZELLIJ", "0");
 
-    let config_options = Options::from_cli(&config.options, opts.command.clone());
     let palette = config.themes.clone().map_or_else(
         || os_input.load_palette(),
         |t| {
@@ -114,7 +116,7 @@ pub fn start_client(
 
     let full_screen_ws = os_input.get_terminal_size_using_fd(0);
     let client_attributes = ClientAttributes {
-        position_and_size: full_screen_ws,
+        size: full_screen_ws,
         palette,
     };
 
@@ -135,7 +137,7 @@ pub fn start_client(
                 client_attributes,
                 Box::new(opts),
                 Box::new(config_options.clone()),
-                layout,
+                layout.unwrap(),
             )
         }
     };
@@ -293,6 +295,7 @@ pub fn start_client(
     );
 
     os_input.disable_mouse();
+    info!("{}", exit_msg);
     os_input.unset_raw_mode(0);
     let mut stdout = os_input.get_stdout_writer();
     let _ = stdout.write(goodbye_message.as_bytes()).unwrap();
