@@ -202,12 +202,14 @@ pub enum ScreenContext {
     ScrollUpAt,
     ScrollDown,
     ScrollDownAt,
+    ScrollToBottom,
     PageScrollUp,
     PageScrollDown,
     ClearScroll,
     CloseFocusedPane,
     ToggleActiveSyncTab,
     ToggleActiveTerminalFullscreen,
+    TogglePaneFrames,
     SetSelectable,
     SetInvisibleBorders,
     SetFixedHeight,
@@ -226,6 +228,7 @@ pub enum ScreenContext {
     MouseRelease,
     MouseHold,
     Copy,
+    ToggleTab,
 }
 
 /// Stack call representations corresponding to the different types of [`PtyInstruction`]s.
@@ -234,6 +237,7 @@ pub enum PtyContext {
     SpawnTerminal,
     SpawnTerminalVertically,
     SpawnTerminalHorizontally,
+    UpdateActivePane,
     NewTab,
     ClosePane,
     CloseTab,
