@@ -45,6 +45,9 @@ pub enum ConfigError {
     IoPath(io::Error, PathBuf),
     // Internal Deserialization Error
     FromUtf8(std::string::FromUtf8Error),
+    // Missing the tab section in the layout.
+    Layout(LayoutMissingTabSectionError),
+    LayoutPartAndTab(LayoutPartAndTabError),
 }
 
 impl Default for Config {
@@ -96,16 +99,21 @@ impl TryFrom<&CliArgs> for Config {
 impl Config {
     /// Uses defaults, but lets config override them.
     pub fn from_yaml(yaml_config: &str) -> ConfigResult {
-        let config_from_yaml: ConfigFromYaml = serde_yaml::from_str(yaml_config)?;
-        let keybinds = Keybinds::get_default_keybinds_with_config(config_from_yaml.keybinds);
-        let options = Options::from_yaml(config_from_yaml.options);
-        let themes = config_from_yaml.themes;
+        let config_from_yaml: Option<ConfigFromYaml> = serde_yaml::from_str(yaml_config)?;
 
-        Ok(Config {
-            keybinds,
-            options,
-            themes,
-        })
+        match config_from_yaml {
+            None => Ok(Config::default()),
+            Some(config) => {
+                let keybinds = Keybinds::get_default_keybinds_with_config(config.keybinds);
+                let options = Options::from_yaml(config.options);
+                let themes = config.themes;
+                Ok(Config {
+                    keybinds,
+                    options,
+                    themes,
+                })
+            }
+        }
     }
 
     /// Deserializes from given path.
@@ -129,6 +137,75 @@ impl Config {
     }
 }
 
+// TODO: Split errors up into separate modules
+#[derive(Debug, Clone)]
+pub struct LayoutMissingTabSectionError;
+#[derive(Debug, Clone)]
+pub struct LayoutPartAndTabError;
+
+impl fmt::Display for LayoutMissingTabSectionError {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(
+            f,
+            "MissingTabSectionError:
+There needs to be exactly one `tabs` section specified in the layout file, for example:
+---
+direction: Horizontal
+parts:
+  - direction: Vertical
+  - direction: Vertical
+    tabs:
+      - direction: Vertical
+      - direction: Vertical
+  - direction: Vertical
+"
+        )
+    }
+}
+
+impl std::error::Error for LayoutMissingTabSectionError {
+    fn description(&self) -> &str {
+        "One tab must be specified per Layout."
+    }
+}
+
+impl fmt::Display for LayoutPartAndTabError {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(
+            f,
+            "LayoutPartAndTabError:
+The `tabs` and `parts` section should not be specified on the same level in the layout file, for example:
+---
+direction: Horizontal
+parts:
+  - direction: Vertical
+  - direction: Vertical
+tabs:
+  - direction: Vertical
+  - direction: Vertical
+  - direction: Vertical
+
+should rather be specified as:
+---
+direction: Horizontal
+parts:
+  - direction: Vertical
+  - direction: Vertical
+    tabs:
+      - direction: Vertical
+      - direction: Vertical
+      - direction: Vertical
+"
+        )
+    }
+}
+
+impl std::error::Error for LayoutPartAndTabError {
+    fn description(&self) -> &str {
+        "The `tabs` and parts section should not be specified on the same level."
+    }
+}
+
 impl Display for ConfigError {
     fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
         match self {
@@ -138,6 +215,12 @@ impl Display for ConfigError {
             }
             ConfigError::Serde(ref err) => write!(formatter, "Deserialization error: {}", err),
             ConfigError::FromUtf8(ref err) => write!(formatter, "FromUtf8Error: {}", err),
+            ConfigError::Layout(ref err) => {
+                write!(formatter, "There was an error in the layout file, {}", err)
+            }
+            ConfigError::LayoutPartAndTab(ref err) => {
+                write!(formatter, "There was an error in the layout file, {}", err)
+            }
         }
     }
 }
@@ -149,6 +232,8 @@ impl std::error::Error for ConfigError {
             ConfigError::IoPath(ref err, _) => Some(err),
             ConfigError::Serde(ref err) => Some(err),
             ConfigError::FromUtf8(ref err) => Some(err),
+            ConfigError::Layout(ref err) => Some(err),
+            ConfigError::LayoutPartAndTab(ref err) => Some(err),
         }
     }
 }
@@ -171,6 +256,18 @@ impl From<std::string::FromUtf8Error> for ConfigError {
     }
 }
 
+impl From<LayoutMissingTabSectionError> for ConfigError {
+    fn from(err: LayoutMissingTabSectionError) -> ConfigError {
+        ConfigError::Layout(err)
+    }
+}
+
+impl From<LayoutPartAndTabError> for ConfigError {
+    fn from(err: LayoutPartAndTabError) -> ConfigError {
+        ConfigError::LayoutPartAndTab(err)
+    }
+}
+
 // The unit test location.
 #[cfg(test)]
 mod config_test {
@@ -183,8 +280,10 @@ mod config_test {
     #[test]
     fn try_from_cli_args_with_config() {
         let arbitrary_config = PathBuf::from("nonexistent.yaml");
-        let mut opts = CliArgs::default();
-        opts.config = Some(arbitrary_config);
+        let opts = CliArgs {
+            config: Some(arbitrary_config),
+            ..Default::default()
+        };
         println!("OPTS= {:?}", opts);
         let result = Config::try_from(&opts);
         assert!(result.is_err());
@@ -193,11 +292,13 @@ mod config_test {
     #[test]
     fn try_from_cli_args_with_option_clean() {
         use crate::setup::Setup;
-        let mut opts = CliArgs::default();
-        opts.command = Some(Command::Setup(Setup {
-            clean: true,
-            ..Setup::default()
-        }));
+        let opts = CliArgs {
+            command: Some(Command::Setup(Setup {
+                clean: true,
+                ..Setup::default()
+            })),
+            ..Default::default()
+        };
         let result = Config::try_from(&opts);
         assert!(result.is_ok());
     }
